#HELP
HELP_DEVICES = "List available devices in your galaxest"
HELP_CONNECT = "Connect to a device in galaxest to your machine"
HELP_DISCONNECT = "Disconnect a galaxest's device from your machine"
HELP_RESET_CONFIG = "Reset your spaceship configurations"
HELP_SHOW_CONFIG = "Show your spaceship configurations"
HELP_RUN = "Run a test from your automation framework"
HELP_MY_DEVICES = "See devices from galaxest connected to this machine."
HELP_OPTS = "Specify more arguments for your test run"
HELP_PARALLEL_N = "Run the test by specifying desired amount of devices"
HELP_PARALLEL_OS = "Run the test by specifying desired os versions"
HELP_PARALLEL_ID = "Run the test by specifying device ids"
HELP_SKIP_DISCONNECT = "Skip auto disconnect device after test finished"

#SUCCESS
SUCCESS_SETUP = "Done! Your spaceship is ready to explore the galaxest"
SUCCESS_DEVICE_CONNECT = "successfully connected to your adb as"
SUCCESS_DEVICE_DISCONNECT = "device successfully disconnected from your machine"

#ERROR
ERROR_CD_TOGETHER = "Can't connect and disconnect at one time. Please choose one."
ERROR_DISCONNECT_NO_ID = "Can't find device to be disconnected. Please specify the device's serial!"
ERROR_DISCONNECT_ID_NOT_FOUND = "galaxest doesn't see this device connected"
ERROR_CONNECT_DEVICE = "Can't connect to the desired device. Wanna try another device?"
ERROR_DEVICE_BUSY = "Device is currently running another automation. Please re-run after it finish or choose another device."
ERROR_DEVICE_UNAVAILABLE = "The desired device is currently unavailable. You can see available devices by run 'galaxest -l'"
ERROR_DEVICE_NOT_FOUND = "Can't find any devices match to your criteria to run the test"
ERROR_STF_TEST_CONN = "Failed to connect to your OpenSTF!"
ERROR_TESTFW_NOT_FOUND = "Failed to find your Automation framework"
ERROR_CONNECT_ADB_KEY = "Somethings wrong with your account's adb key. Please recheck it"
ERROR_ADB_KEY_NOT_FOUND = "You don't have any adb key. Please check it on Settings page at your OpenSTF Dashboard."
ERROR_DISCONNECT_HUNG = "It may failed to disconnect the device"
ERROR_STF_CONFIG = "Something wrong with the OpenSTF configuration. Please check your app_config.json first."
ERROR_STF_FETCH_DEVICES = "failed to get list of devices"
ERROR_STF_STOP_DEVICE = "failed to stop use the device"
ERROR_STF_USE_DEVICE = "failed to use the device"
ERROR_CHOOSE_PARALLEL_TYPE = "Please choose only one type of parallel execution"

#INFO
INFO_SETUP_FIRST = "Hi! This is your first time exploring galaxest."
INFO_SETUP_SUB = "Let's setup your spaceship first!"
INFO_SETUP_Q_TEST_FW = "What UI automation framework do you use?"
INFO_SETUP_Q_DEVICE_FARM = "What are device farm sources do you have? (press right arrow button on your keyboard to choose)"
INFO_SETUP_Q_KATALON_PATH = "Where is your Katalon Application?"
INFO_SETUP_Q_KATALON_PROJECT_PATH = "Where is your Katalon project?"
INFO_SETUP_Q_KATALON_PROJECT_FILE = "Where is your katalon .prj file?"
INFO_SETUP_Q_STF_HOST = "What's your OpenSTF host (e.g. http://172.0.0.1:7100)"
INFO_SETUP_Q_STF_TOKEN = "What's your OpenSTF user API Token"
INFO_SETUP_STF_TEST_CONN = "Testing the connection to your OpenSTF..."
INFO_PROMPT_READY = "Are you ready?"
INFO_YES = "Yes"
INFO_NO = "No"
INFO_DEVICE_CONNECTING = "connecting the device..."
INFO_DEVICE_DISCONNECTING = "disconnecting the device..."
INFO_LOGGED_IN = "You are logged in as"
INFO_KATALON_START = "Starting Katalon automation at"
